@@ -181,6 +181,75 @@
         <translation>Connections: script expected</translation>
     </message>
 </context>
+<context>
+    <name>QQmlDebugServerImpl</name>
+    <message>
+        <source>QML Debugger: Invalid argument &quot;%1&quot; detected. Ignoring the same.</source>
+        <translation>QML Debugger: Invalid argument &quot;%1&quot; detected. Ignoring the same.</translation>
+    </message>
+    <message>
+        <source>QML Debugger: Ignoring &quot;-qmljsdebugger=%1&quot;.</source>
+        <translation>QML Debugger: Ignoring &quot;-qmljsdebugger=%1&quot;.</translation>
+    </message>
+    <message>
+        <source>The format is &quot;-qmljsdebugger=[file:&lt;file&gt;|port:&lt;port_from&gt;][,&lt;port_to&gt;][,host:&lt;ip address&gt;][,block][,services:&lt;service&gt;][,&lt;service&gt;]*&quot;</source>
+        <translation>The format is &quot;-qmljsdebugger=[file:&lt;file&gt;|port:&lt;port_from&gt;][,&lt;port_to&gt;][,host:&lt;ip address&gt;][,block][,services:&lt;service&gt;][,&lt;service&gt;]*&quot;</translation>
+    </message>
+    <message>
+        <source>&quot;file:&quot; can be used to specify the name of a file the debugger will try to connect to using a QLocalSocket. If &quot;file:&quot; is given any &quot;host:&quot; and&quot;port:&quot; arguments will be ignored.</source>
+        <translation>&quot;file:&quot; can be used to specify the name of a file the debugger will try to connect to using a QLocalSocket. If &quot;file:&quot; is given any &quot;host:&quot; and&quot;port:&quot; arguments will be ignored.</translation>
+    </message>
+    <message>
+        <source>&quot;host:&quot; and &quot;port:&quot; can be used to specify an address and a single port or a range of ports the debugger will try to bind to with a QTcpServer.</source>
+        <translation>&quot;host:&quot; and &quot;port:&quot; can be used to specify an address and a single port or a range of ports the debugger will try to bind to with a QTcpServer.</translation>
+    </message>
+    <message>
+        <source>&quot;block&quot; makes the debugger and some services wait for clients to be connected and ready before the first QML engine starts.</source>
+        <translation>&quot;block&quot; makes the debugger and some services wait for clients to be connected and ready before the first QML engine starts.</translation>
+    </message>
+    <message>
+        <source>&quot;services:&quot; can be used to specify which debug services the debugger should load. Some debug services interact badly with others. The V4 debugger should not be loaded when using the QML profiler as it will force any V4 engines to use the JavaScript interpreter rather than the JIT. The following debug services are available by default:</source>
+        <translation>&quot;services:&quot; can be used to specify which debug services the debugger should load. Some debug services interact badly with others. The V4 debugger should not be loaded when using the QML profiler as it will force any V4 engines to use the JavaScript interpreter rather than the JIT. The following debug services are available by default:</translation>
+    </message>
+    <message>
+        <source>The QML debugger</source>
+        <translation>The QML debugger</translation>
+    </message>
+    <message>
+        <source>The V4 debugger</source>
+        <translation>The V4 debugger</translation>
+    </message>
+    <message>
+        <source>The QML inspector</source>
+        <translation>The QML inspector</translation>
+    </message>
+    <message>
+        <source>The QML profiler</source>
+        <translation>The QML profiler</translation>
+    </message>
+    <message>
+        <source>Allows the client to delay the starting and stopping of
+		  QML engines until other services are ready. QtCreator
+		  uses this service with the QML profiler in order to
+		  profile multiple QML engines at the same time.</source>
+        <translation>Allows the client to delay the starting and stopping of
+		  QML engines until other services are ready. QtCreator
+		  uses this service with the QML profiler in order to
+		  profile multiple QML engines at the same time.</translation>
+    </message>
+    <message>
+        <source>Sends qDebug() and similar messages over the QML debug
+		  connection. QtCreator uses this for showing debug
+		  messages in the debugger console.</source>
+        <translation>Sends qDebug() and similar messages over the QML debug
+		  connection. QtCreator uses this for showing debug
+		  messages in the debugger console.</translation>
+    </message>
+    <message>
+        <source>Other services offered by qmltooling plugins that implement QQmlDebugServiceFactory and which can be found in the standard plugin paths will also be available and can be specified. If no &quot;services&quot; argument is given, all services found this way, including the default ones, are loaded.</source>
+        <translation>Other services offered by qmltooling plugins that implement QQmlDebugServiceFactory and which can be found in the standard plugin paths will also be available and can be specified. If no &quot;services&quot; argument is given, all services found this way, including the default ones, are loaded.</translation>
+    </message>
+</context>
 <context>
     <name>QQmlDelegateModel</name>
     <message>
@@ -341,6 +410,10 @@
 </context>
 <context>
     <name>QQmlEnumTypeResolver</name>
+    <message>
+        <source>Invalid property assignment: Enum value &quot;%1&quot; cannot start with a lowercase letter</source>
+        <translation>Invalid property assignment: Enum value &quot;%1&quot; cannot start with a lowercase letter</translation>
+    </message>
     <message>
         <source>Invalid property assignment: &quot;%1&quot; is a read-only property</source>
         <translation>Invalid property assignment: &quot;%1&quot; is a read-only property</translation>
@@ -407,6 +480,10 @@
         <source>module &quot;%1&quot; plugin &quot;%2&quot; not found</source>
         <translation>module &quot;%1&quot; plugin &quot;%2&quot; not found</translation>
     </message>
+    <message>
+        <source>library loading is disabled</source>
+        <translation>kirjastojen lataaminen ei ole käytössä</translation>
+    </message>
     <message>
         <source>&quot;%1&quot; version %2.%3 is defined more than once in module &quot;%4&quot;</source>
         <translation>&quot;%1&quot; version %2.%3 is defined more than once in module &quot;%4&quot;</translation>
@@ -1188,6 +1265,13 @@
         <translation>setSource: value is not an object</translation>
     </message>
 </context>
+<context>
+    <name>QQuickMouseEvent</name>
+    <message>
+        <source>MouseEvent is only available within handlers in MouseArea</source>
+        <translation>MouseEvent is only available within handlers in MouseArea</translation>
+    </message>
+</context>
 <context>
     <name>QQuickOpenGLInfo</name>
     <message>
@@ -1276,11 +1360,6 @@
         <translatorcomment>Tämä viesti on suomennettu, koska siitä voi olla hyötyä myös ongelmaa selvittävälle Qt:lla tehdyn ohjelman loppukäyttäjälle eikä tämän viestin suomentamisen luulisi vaikeuttavan ongelman selvittämistä.</translatorcomment>
         <translation>Ei voi avata: %1</translation>
     </message>
-    <message>
-        <source>Invalid image data: %1</source>
-        <translatorcomment>Tämä viesti on suomennettu, koska siitä voi olla hyötyä myös ongelmaa selvittävälle Qt:lla tehdyn ohjelman loppukäyttäjälle eikä tämän viestin suomentamisen luulisi vaikeuttavan ongelman selvittämistä.</translatorcomment>
-        <translation>Virheellinen kuvadata: %1</translation>
-    </message>
 </context>
 <context>
     <name>QQuickPropertyAnimation</name>
@@ -1424,6 +1503,17 @@ Asenna ajuri, joka tukee OpenGL 2.0:aa tai uudempaa. Mikäli sellaisen asentamin
         <translation>Incorrectly specified signal assignment</translation>
     </message>
 </context>
+<context>
+    <name>SignalTransition</name>
+    <message>
+        <source>Cannot assign to non-existent property &quot;%1&quot;</source>
+        <translation>Cannot assign to non-existent property &quot;%1&quot;</translation>
+    </message>
+    <message>
+        <source>SignalTransition: script expected</source>
+        <translation>SignalTransition: script expected</translation>
+    </message>
+</context>
 <context>
     <name>qmlRegisterType</name>
     <message>
